% !TeX root = main.tex
%%==============================================================================
%%                            WZL LaTex Class
%%                                 V2.0
%%             Dissertations, project reports, bachelor theses, master theses
%%
%%------------------------------------------------------------------------------
%%
%% Class developed by:
%%
%% Amon Göppert (gpp)
%% Laboratory for Machine Tools and Production Engineering WZL | RWTH Aachen
%% Chair of Production Metrology and Quality Management
%% Department Model-based Systems
%% Group Metrology Assisted Assembly
%%
%% Production Engineering Cluster
%% Campus-Boulevard 30, 52074 Aachen | GERMANY
%% Phone: +49 241 80-20599
%% mailto: a.goeppert@wzl.rwth-aachen.de
%%
%%
%%------------------------------------------------------------------------------
%%
%% Aachen, October 2019
%% based on LaTeX `book.cls'
%% This specific file is the class file, which is needs to be specified in the command \documentclass{}
%%
%------------------------------------------------------------------
%%
%%
%% Class edited by:
%%
%% Tobias Hamann (hmt)
%% Group Leader
%% 
%% Laboratory for Machine Tools and Production 
%% Engineering WZL of RWTH Aachen
%% Chair of Production Metrology and Quality Management
%% Department for Organizational Development | Industrial Capabilities
%% Production Engineering Cluster
%% Campus-Boulevard 30
%% 52074 Aachen | GERMANY
%% Phone: +49 151 72921981
%% mailto: t.hamann@wzl-mq.rwth-aachen.de
%%
%%
%%------------------------------------------------------------------------------
%%
%% Aachen, May 2022
%% Changed the file to be working with MiKTeX, TexStudio and Citavi 6 on a local machine rather than on an online plattform. Also cleaned up the code from development artifacts and added comments for understanding.
%%
%%
%------------------------------------------------------------------
%%
%%
%% Class edited by:
%%
%% Mark Sanders (sdr)
%% 
%% Laboratory for Machine Tools and Production 
%% Engineering WZL of RWTH Aachen
%% Chair of Production Metrology and Quality Management
%% Department for Organizational Development | Industrial Capabilities
%% Production Engineering Cluster
%% Campus-Boulevard 30
%% 52074 Aachen | GERMANY
%% Phone: 
%% mailto: 
%%
%%
%%------------------------------------------------------------------------------
%%
%% Aachen, 
%% 
%%

%==============================================================================
%%
%------------------------------------------------------------------
%%
%%
%% Class edited by: Mark Sanders and Tobias Hamann
%%------------------------------------------------------------------------------
%%
%% Aachen, Feburary 2025
%% Complete Rework and merging of previous works to create a common template.
%% What else can we say except you're welcome!
%%

%==============================================================================

%% ====== Class commands ======
\NeedsTeXFormat{LaTeX2e}
% \ProvidesClass{WZLtemplate}[2019/08/15 Example LaTeX class]
\ProvidesClass{format/WZLTemplate}[WZL Thesis]

%%----OPTIONS----

%% 'sans' option
\DeclareOption{sans}{
    \renewcommand{\familydefault}{\sfdefault}
}

%% 'de' option
\DeclareOption{de}{
    \newcommand{\longlang}{ngerman}
    \newcommand{\shortlang}{de}
    \newcommand{\tmpacronymname}{Abkürzungsverzeichnis}
    \newcommand{\tmpreferencename}{Literaturverzeichnis}
    \newcommand{\tmpsymbolname}{Symbolverzeichnis}
    \newcommand{\tmpglossaryname}{Glossar}
    \PassOptionsToPackage{ngerman}{babel}
    \newcommand{\Autoref}[1]{{\autoref{#1}}}
}

%% 'en' option
\DeclareOption{en}{
    \newcommand{\longlang}{english}
    \newcommand{\shortlang}{en}
    \newcommand{\tmpacronymname}{Table of Acronyms}
    \newcommand{\tmpreferencename}{References}
    \newcommand{\tmpsymbolname}{List of Symbols}
    \newcommand{\tmpglossaryname}{Glossary}
    \PassOptionsToPackage{english}{babel}
    \AtBeginDocument{
        \renewcommand{\figureautorefname}{figure} % is otherwise capitalized
        \renewcommand{\subfigureautorefname}{figure}
        % \renewcommand{\subsubsectionautorefname}{section}
    }
    \newcommand{\Autoref}[1]{\capitalisewords{\autoref{#1}}}
}

%%----PROCESSING OPTIONS----

%% Declare, where language specific documents can be found, such as frontmatter etc. The path corresponds to the short name of the language choosen via the language option.
\def\input@path{{format/\shortlang/}}

\def\usefiramath{0}
\DeclareOption{usefiramath}{\def\usefiramath{1}}

\def\papersize{4}
\DeclareOption{a5paper}{\def\papersize{5}}
\DeclareOption{a4paper}{\def\papersize{4}}

%% Pass all unrecognized options to the base class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{extreport}}

% Process all given options
\ProcessOptions\relax


%%----SET DOCUMENT PROPERTIES----
\input{format/WZLTemplate_files/SET_DocumentProperties.tex}





\usepackage[hang,flushmargin,]{footmisc} %% Remove indentation of footnotes
\usepackage{mfirstuc}
\RequirePackage[titles]{tocloft} % Placement of table of contents, list of figures and list of tables
\cftsetindents{figure}{0em}{3.5em}
\cftsetindents{table}{0em}{3.5em}
\setlength{\cftsecnumwidth}{3em}
\setlength{\cftsubsecnumwidth}{4em}
\setlength{\cftsubsubsecnumwidth}{4em}
\setlength{\cftbeforechapskip}{3pt}
\setlength{\cftbeforesecskip}{3pt}
\setlength{\cftbeforesubsubsecskip}{2pt}

\renewcommand{\theHchapter}{\arabic{chapter}\thechapter}



%%----IMPORT USEFULL PACKAGES----

% Setup Colors
\RequirePackage{xcolor}
\input{format/rwthcolors/LaTeX/rwthcolors}

%% Context sensitive quoting
\RequirePackage{csquotes}

%% Standard math packages
\RequirePackage[intlimits]{amsmath}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{enumitem}

%% Enable bold font within math environments
\RequirePackage{bm}

%% Package for creating listing with \enumerate
\RequirePackage{enumerate}

\RequirePackage{graphicx}
\renewcommand{\textfraction}{0.10}
\renewcommand{\floatpagefraction}{0.90}

%% For absolute placement of figures and creation of vector graphics
\RequirePackage{tikz}
\usetikzlibrary{calc}
% TODO \RequirePackage{ulem} Probleme ohne [normalem]

%% Strict placement of figures, tables, etc. referring to the tex source code
%% Usage: \begin{figure}[H]
\RequirePackage{float}

\RequirePackage{wrapfig}

%% Alternative style of tables
\RequirePackage{booktabs}

\RequirePackage{tabularray}

%% Advanced table package for use-defined width definitions
\RequirePackage{tabularx}

%% Defines a \FloatBarrier command, beyond which floats may not pass; useful, for example, to ensure all floats for a section appear before the next \section command. 
\RequirePackage[section]{placeins}


%% Placing captions within figure or table environments
%% Usage: \caption{Place your caption here.}
\RequirePackage{caption}
\RequirePackage{subcaption}

% Setting up cations for figures
\captionsetup[figure]{
    labelfont=bf,
	% TODO justification=raggedright,
    justification=justified,
    singlelinecheck=false
}

%TODO \captionsetup[table]{labelfont=bf}
% Setting up cations for tables
\captionsetup[table]{
	labelfont=bf,
	justification=raggedright,
	singlelinecheck=false
}

%% Subliminal refinements towards typographical perfection 
\RequirePackage{microtype}

%% Insert current date and time
\usepackage{datetime}
\newdateformat{verbosedate}{\the\day. \monthname[\THEMONTH] \THEYEAR}

%% For inserting external PDFs
\RequirePackage{pdfpages}

%% For inserting tabulator environments
\RequirePackage{Tabbing}

% Package to create a dummy text with \blindtext
\usepackage{blindtext}


%% TODO ----SET UP Unused packages----
%% Remove indentation of footnotes
\usepackage[
    hang,
    flushmargin,
    ]{footmisc} 


%%----SET UP CUSTOM COLORS----



%%----SET UP TODO COMMANDS----

%% Use \todo{} for inline-todo notes
\RequirePackage[color=RWTHBlau25]{todonotes} %% Use \todo{} for inline-todo notes
\RequirePackage{regexpatch}
\makeatletter
\xpatchcmd{\@todo}{\setkeys{todonotes}{#1}}{\setkeys{todonotes}{inline,#1}}{}{}
\makeatother

%%----SET UP TABLE OF CONTENTS----

%% Placement of table of contents, list of figures and list of tables
\renewcommand{\cfttoctitlefont}{}
\makeatletter
% \pretocmd{\l@subsubsection}{\vspace{5pt}}{}{} % Increase space after subsubsections
\makeatother

%%----SET UP BIBLIOGRAPHY----

%% bibliography for defining macros in .tex-documents
%% processing backend: biber
%% further explanations: https://tex.stackexchange.com/a/299286
\RequirePackage[
    backend=biber,
    style=alphabetic,
    maxalphanames=1,
    isbn=true,
    url=true,
    urldate=iso,
    giveninits=true,
    maxnames=10,
    date=iso,
    seconds=true,
    %firstinits=true
]{biblatex}

%% WZL citation style: 4 capital letters & short year
\DeclareLabelalphaTemplate{
    \labelelement{
        \field[final]{shorthand}
        \field{label}
        \field[strwidth=4,strside=left,uppercase=true]{labelname}
    }
    \labelelement{
        \field[strwidth=2,strside=right]{year}
    }
}
\setlength{\biblabelsep}{2pt}
% \RequirePackage{pdfcomment}
% % Redefine \cite to include tooltips
% \let\oldcite\cite
% \renewcommand{\cite}[1]{
% \pdftooltip{\oldcite{#1}}{\fullcite{#1}}
% % \oldcite{#1}
% }

%% Bibliograph tweak: remove "+"-sign as an abbrevation for et. al
\renewcommand*{\labelalphaothers}{} 

%% Avoid overfull hbox in bibliography
\emergencystretch=1em 

%% No identation when a new paragraph starts
\setlength{\parindent}{0pt} 

\setlength{\skip\footins}{1cm} % footnote margin
\renewcommand{\footnoterule}
{{\color{\chaptercolor}
            \noindent\rule[3pt]{\textwidth}{0.4pt}
        }
}

%%----SET UP TABLE OF CONTENTS----


%%----SET UP LIST OF FIGURES & LIST OF TABLES----

%% LOFLOT - List of figures & list of tables
\newcommand{\loflot}{
	%% List of figures
	\stepcounter{romancounter}
	\let\tmplistfigurename\listfigurename
	\renewcommand{\listfigurename}{\Roman{romancounter}\hspace{1em}\tmplistfigurename}
	\cleardoublepage\phantomsection\addcontentsline{toc}{chapter}{\listfigurename}
	\listoffigures
	\newpage
	%% List of tables
	\stepcounter{romancounter}
	\let\tmplisttablename\listtablename
	\renewcommand{\listtablename}{\Roman{romancounter}\hspace{1em}\tmplisttablename}
	\cleardoublepage\phantomsection\addcontentsline{toc}{chapter}{\listtablename}
	\listoftables
	\newpage
	
	%% Start of main text
	\pagenumbering{arabic}
	\setcounter{page}{1}
	\setcounter{chapter}{0}
	\renewcommand{\thechapter}{\arabic{chapter}}
	
}


%%----MISCELLANEOUS----

%% Reduce error messages for horz. & vert. overstretching of text
\hbadness=10001
\vbadness=10001
\widowpenalty=10000
\clubpenalty=10000
\brokenpenalty=10000
\predisplaypenalty=10000
\postdisplaypenalty=10000
\displaywidowpenalty=10000
\raggedbottom

\RequirePackage{blindtext}
\RequirePackage{url}
\RequirePackage{booktabs}
\RequirePackage{chronosys}
\setupchronology{color=RWTHBlau25,dates=false, height=20pt}
\setupchronoperiode{color=RWTHBlau100, textstyle=\footnotesize,dates=false,datestyle=\footnotesize\centering}
\setupchronoevent{textstyle=\footnotesize,datestyle=\footnotesize\centering, textwidth=20ex, colorbox=white}

\setcounter{MaxMatrixCols}{32}
% \RequirePackage[autoplay,loop,controls=true]{animate}
\RequirePackage{fontspec}
\newfontfamily\arialfont[NFSSFamily=arial]{Arial}
\RequirePackage[inkscapelatex=false, inkscapepath=svgsubdir, pretex=\fontfamily{arial}\selectfont]{svg}
\RequirePackage{adjustbox} % For limiting table width
\RequirePackage{tcolorbox}
\setlength{\fboxsep}{1pt}
\RequirePackage{anyfontsize}

\RequirePackage{unicode-math}
\ifnum\usefiramath=1
    \message{usefiramath: Fira Math selected}
    \usepackage{firamath-otf}
    \setmathfont{Fira Math}
    \setmathfont[range={"22EF, "22EE, "22F1, "2700-"27BF,"1F600-"1F64F}]{Latin Modern Math}
\else
    \message{usefiramath: Default math font selected}
\fi

\RequirePackage[
    colorlinks=true,
    linkcolor=linkcolor,
    citecolor=linkcolor,
    filecolor=linkcolor,
    urlcolor=linkcolor,
    pdfborderstyle={/S/U/W 1}, % underline links
    linktoc=all,
    bookmarksdepth=2,
]{hyperref} % Make links, cites, toc, etc. clickable

\RequirePackage[
    printonlyused,
    withpage,
    %			smaller,
    %			nohyperlinks,
    % nolist
]{acronym}
\usepackage[
    hyperfirst=true,
    automake=immediate,
    symbols,
    section=chapter,
]
{glossaries-extra}
% Define a custom dotfill for glossaries
\def\Dotfill{\leavevmode\xleaders\hbox to .8em{\hss.\hss}\hfill\kern0pt}
\makeglossaries
\input{format/symbols}
\input{format/glossary}

\renewcommand\mkbibacro[1]{{\footnotesize\MakeUppercase{#1}}}

\newcommand\ctformatchapter[1]{\parbox[t]{\dimexpr\textwidth-4em\relax}{\raggedright#1}}

% \titleformat{\chapter}[display]{\vspace{-8em}\raggedleft{
%         {\color{ctcolormain}\rule[-5pt]{2pt}{5cm}}\quad{\color{ctcolormain}\fontsize{60}{60}\selectfont\thechapter}
%     }
% }{-2.1em}{\ctformatchapter}[\phantomsection]

\colorlet{linkcolor}{RWTHBlau100}
\newcommand{\chaptercolor}{RWTHBlau100}

% sourcemap configuration for weird Citavi...
\DeclareSourcemap{
    \maps[
        datatype = bibtex,
        overwrite = true
    ]{
        \map{
            \step[
                fieldsource=doi,
                match=\regexp{\{\\textunderscore\}|\{\\textunderscore\s+\}|\{\\_\}|\{\\_\s+\}},
                replace=_,
            ]}
    }
}
\DeclareSourcemap{
    \maps[datatype=bibtex]{
        \map{
            \step[fieldsource=url, final=true]
            \step[fieldset=verba, origfieldval, final=true]
            \step[fieldsource=verba, match=\regexp{\A(ht|f)tp(s)?:\/\/(www\.)?}, replace={}]
        }
    }
}

\DeclareFieldFormat{url}{%
    \mkbibacro{URL}\addcolon\space
    \href{#1}{\nolinkurl{\thefield{verba}}}}

\endinput
%%----END OF FILE----